package App::daftarnama::reseller;

our $DATE = '2021-05-26'; # DATE
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: CLI to access reseller API on DaftarNama.id

__END__

=pod

=encoding UTF-8

=head1 NAME

App::daftarnama::reseller - CLI to access reseller API on DaftarNama.id

=head1 VERSION

This document describes version 0.003 of App::daftarnama::reseller (from Perl distribution App-daftarnama-reseller), released on 2021-05-26.

=head1 SYNOPSIS

Please see included script L<daftarnama-reseller>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-daftarnama-reseller>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-daftarnama-reseller>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-daftarnama-reseller/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<WWW::DaftarNama::Reseller>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
